@@ -1,46 +1,56 @@
 /*
     Copyright (c) 2010 Tobias Koenig <tokoe@kde.org>
 
-    This program is free software; you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
-    (at your option) any later version.
+    This program is free software; you can redistribute it and/or modify it
+    under the terms of the GNU Library General Public License as published by
+    the Free Software Foundation; either version 2 of the License, or (at your
+    option) any later version.
 
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-    GNU General Public License for more details.
+    This program is distributed in the hope that it will be useful, but WITHOUT
+    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
+    License for more details.
 
     You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+    along with this program.  If not, see <https://www.gnu.org/licenses/>.
 */
 
 #include "davitemmodifyjob.h"
+#include "davjobbase_p.h"
 
 #include "davitemfetchjob.h"
-#include "davmanager.h"
+#include "davmanager_p.h"
 #include "daverror.h"
 
 #include <KIO/Job>
 
 using namespace KDAV;
+namespace KDAV {
+class DavItemModifyJobPrivate : public DavJobBasePrivate
+{
+public:
+    DavItem mItem;
+    DavItem mFreshItem;
+    int mFreshResponseCode = 0;
+};
+}
 
 DavItemModifyJob::DavItemModifyJob(const DavItem &item, QObject *parent)
-    : DavJobBase(parent)
-    , mItem(item)
-    , mFreshResponseCode(0)
+    : DavJobBase(new DavItemModifyJobPrivate, parent)
 {
+    Q_D(DavItemModifyJob);
+    d->mItem = item;
 }
 
 void DavItemModifyJob::start()
 {
+    Q_D(DavItemModifyJob);
     QString headers = QStringLiteral("Content-Type: ");
-    headers += mItem.contentType();
+    headers += d->mItem.contentType();
     headers += QLatin1String("\r\n");
-    headers += QLatin1String("If-Match: ") + mItem.etag();
+    headers += QLatin1String("If-Match: ") + d->mItem.etag();
 
-    KIO::StoredTransferJob *job = KIO::storedPut(mItem.data(), itemUrl(), -1, KIO::HideProgressInfo | KIO::DefaultFlags);
+    KIO::StoredTransferJob *job = KIO::storedPut(d->mItem.data(), itemUrl(), -1, KIO::HideProgressInfo | KIO::DefaultFlags);
     job->addMetaData(QStringLiteral("PropagateHttpHeader"), QStringLiteral("true"));
     job->addMetaData(QStringLiteral("customHTTPHeader"), headers);
     job->addMetaData(QStringLiteral("cookies"), QStringLiteral("none"));
@@ -51,26 +61,31 @@ void DavItemModifyJob::start()
 
 DavItem DavItemModifyJob::item() const
 {
-    return mItem;
+    Q_D(const DavItemModifyJob);
+    return d->mItem;
 }
 
 DavItem DavItemModifyJob::freshItem() const
 {
-    return mFreshItem;
+    Q_D(const DavItemModifyJob);
+    return d->mFreshItem;
 }
 
 int DavItemModifyJob::freshResponseCode() const
 {
-    return mFreshResponseCode;
+    Q_D(const DavItemModifyJob);
+    return d->mFreshResponseCode;
 }
 
 QUrl DavItemModifyJob::itemUrl() const
 {
-    return mItem.url().url();
+    Q_D(const DavItemModifyJob);
+    return d->mItem.url().url();
 }
 
 void DavItemModifyJob::davJobFinished(KJob *job)
 {
+    Q_D(DavItemModifyJob);
     KIO::StoredTransferJob *storedJob = qobject_cast<KIO::StoredTransferJob *>(job);
 
     if (storedJob->error()) {
@@ -85,7 +100,7 @@ void DavItemModifyJob::davJobFinished(KJob *job)
         setErrorTextFromDavError();
 
         if (hasConflict()) {
-            DavItemFetchJob *fetchJob = new DavItemFetchJob(mItem);
+            DavItemFetchJob *fetchJob = new DavItemFetchJob(d->mItem);
             connect(fetchJob, &DavItemFetchJob::result, this, &DavItemModifyJob::conflictingItemFetched);
             fetchJob->start();
         } else {
@@ -115,31 +130,33 @@ void DavItemModifyJob::davJobFinished(KJob *job)
     }
 
     url.setUserInfo(itemUrl().userInfo());
-    mItem.setUrl(DavUrl(url, mItem.url().protocol()));
+    d->mItem.setUrl(DavUrl(url, d->mItem.url().protocol()));
 
-    DavItemFetchJob *fetchJob = new DavItemFetchJob(mItem);
+    DavItemFetchJob *fetchJob = new DavItemFetchJob(d->mItem);
     connect(fetchJob, &DavItemFetchJob::result, this, &DavItemModifyJob::itemRefreshed);
     fetchJob->start();
 }
 
 void DavItemModifyJob::itemRefreshed(KJob *job)
 {
+    Q_D(DavItemModifyJob);
     if (!job->error()) {
         DavItemFetchJob *fetchJob = qobject_cast<DavItemFetchJob *>(job);
-        mItem.setEtag(fetchJob->item().etag());
+        d->mItem.setEtag(fetchJob->item().etag());
     } else {
-        mItem.setEtag(QString());
+        d->mItem.setEtag(QString());
     }
     emitResult();
 }
 
 void DavItemModifyJob::conflictingItemFetched(KJob *job)
 {
+    Q_D(DavItemModifyJob);
     DavItemFetchJob *fetchJob = qobject_cast<DavItemFetchJob *>(job);
-    mFreshResponseCode = fetchJob->latestResponseCode();
+    d->mFreshResponseCode = fetchJob->latestResponseCode();
 
     if (!job->error()) {
-        mFreshItem = fetchJob->item();
+        d->mFreshItem = fetchJob->item();
     }
 
     emitResult();
